@@ -30,7 +30,7 @@ class DBUtils_Test(unittest.TestCase):
 
     def clearPgEnviron(self, prefix='PG'):
         safe = {}
-        for var in os.environ:
+        for var in list(os.environ): # Py2 mutating dict
             if var.startswith(prefix):
                 safe[var] = os.environ.pop(var)
         return safe
@@ -42,11 +42,8 @@ class DBUtils_Test(unittest.TestCase):
                 database: postgres
             """)
         finally:
-            print("cony")
             self.clearPgEnviron()
             os.environ.update(old_pg_vars)
-            print(list(sorted(os.environ)))
-            print(list(sorted(old_pg_vars)))
 
     def test_pgconfig_from_environ__partial_set(self):
         old_pg_vars = self.clearPgEnviron()
@@ -62,11 +59,8 @@ class DBUtils_Test(unittest.TestCase):
                 passfile: mypassfile.txt
             """)
         finally:
-            print("cony")
             self.clearPgEnviron()
             os.environ.update(old_pg_vars)
-            print(list(sorted(os.environ)))
-            print(list(sorted(old_pg_vars)))
 
     def test_pgconfig_from_environ__complete_set(self):
         old_pg_vars = self.clearPgEnviron()
